@@ -86,7 +86,12 @@ def broadcast_urls(gobj, quality='1600', condensed=False):
         % (year, month, day, gobj.gamekey, stype, gobj.gamekey,
            gobj.away.lower(), gobj.home.lower(), gobj.season(), kind,
            i, quality)
-        for i in range(1, 4)
+        for i in range(3, 0, -1)
+        # We count down here because higher numbers seem to take precedent.
+        # For example, the DEN @ NYG game in week 2 of 2013 regular season
+        # game. Using `1` links to valid footage that is only ~40 minutes
+        # long. The real stream uses `2`.
+        # I have no idea if this is a general rule or not.
     ]
 
 
@@ -777,10 +782,6 @@ def _xml_plays(data, coach=True):
         if not start:
             continue
         start = PlayTime(start.get_text().strip())
-
-        # If this start doesn't procede the last start time, skip it.
-        if len(rows) > 0 and start < rows[-1][1]:
-            continue
         rows.append((playid, start, row))
 
     # A predicate for determining whether to ignore a row or not in our final
